@@ -1,7 +1,7 @@
-/* $Id: Handler.java,v 1.8 1999/09/16 04:09:46 boyns Exp $ */
+/* $Id: Handler.java,v 1.11 2000/03/08 15:18:00 boyns Exp $ */
 
 /*
- * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of Muffin.
  *
@@ -23,6 +23,7 @@
 package org.doit.muffin;
 
 import java.io.*;
+import java.util.zip.*;
 import java.net.Socket;
 import java.net.URL;
 import org.doit.io.*;
@@ -168,7 +169,12 @@ class Handler implements Runnable
 		    {
 			reply.setHeaderField("Content-length", currentLength);
 		    }
-		    Main.getLogFile().log(request, reply);
+
+		    LogFile logFile = Main.getLogFile();
+		    if (logFile != null)
+		    {
+			logFile.log(request, reply);
+		    }
 		}
 	    }
 	    while (keepAlive);
@@ -202,6 +208,7 @@ class Handler implements Runnable
 	while (reply == null)
 	{
 	    boolean secure = false;
+	    boolean uncompress = false;
 
 	    filterList = manager.createFilters(request.getURL());
 
@@ -297,6 +304,19 @@ class Handler implements Runnable
 	    /* Filter the reply. */
 	    if (!options.getBoolean("muffin.passthru"))
 	    {
+		/* uncompress gzip encoded html so it can be filtered */
+		if (!options.getBoolean("muffin.dontUncompress")
+		    && "text/html".equals(reply.getHeaderField("Content-type")))
+		{
+		    String encoding = reply.getHeaderField("Content-Encoding");
+		    if (encoding != null && encoding.indexOf("gzip") != -1)
+		    {
+			reply.removeHeaderField("Content-Encoding");
+			reply.removeHeaderField("Content-length");
+			uncompress = true;
+		    }
+		}
+
 		filter(reply);
 	    }
 
@@ -350,7 +370,7 @@ class Handler implements Runnable
 	    {
 		try
 		{
-		    processContent();
+		    processContent(uncompress);
 		}
 		catch (IOException e)
 		{
@@ -465,7 +485,7 @@ class Handler implements Runnable
 	return new ByteArrayInputStream(chunks.toByteArray());
     }
     
-    void processContent() throws IOException
+    void processContent(boolean uncompress) throws IOException
     {
 	InputStream in;
 	boolean chunked = false;
@@ -486,6 +506,10 @@ class Handler implements Runnable
 	    System.out.println("No inputstream");
 	    return;
 	}
+	else if (uncompress)
+	{
+	    in = new GZIPInputStream(in);
+	}
 
 	if (options.getBoolean("muffin.passthru"))
 	{
