@@ -1,7 +1,7 @@
-/* $Id: Main.java,v 1.12 1999/09/16 04:11:17 boyns Exp $ */
+/* $Id: Main.java,v 1.21 2000/03/29 15:11:53 boyns Exp $ */
 
 /*
- * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of Muffin.
  *
@@ -50,7 +50,7 @@ import org.doit.util.*;
 public class Main extends MuffinFrame
     implements ActionListener, WindowListener, ConfigurationListener
 {
-    private static String version = "0.9";
+    private static String version = "0.9.3a";
     private static String url = "http://muffin.doit.org/";
     private static String host;
 
@@ -140,6 +140,10 @@ public class Main extends MuffinFrame
 	item.setActionCommand("doDisable");
 	item.addActionListener(this);
 	menu.add(item);
+	item = new MenuItem("Suspend");
+	item.setActionCommand("doSuspend");
+	item.addActionListener(this);
+	menu.add(item);
 	item = new MenuItem("Quit");
 	item.setActionCommand("doQuit");
 	item.addActionListener(this);
@@ -283,6 +287,22 @@ public class Main extends MuffinFrame
 	    item.setLabel("Disable Filtering");
 	    options.putBoolean("muffin.passthru", false);
 	}
+	else if ("doSuspend".equals(arg))
+	{
+	    MenuItem item = (MenuItem) event.getSource();
+	    item.setActionCommand("doResume");
+	    item.setLabel("Resume");
+	    server.suspend();
+	    monitor.suspend();
+	}
+	else if ("doResume".equals(arg))
+	{
+	    MenuItem item = (MenuItem) event.getSource();
+	    item.setActionCommand("doSuspend");
+	    item.setLabel("Suspend");
+	    server.resume();
+	    monitor.resume();
+	}
 	else if ("doConnections".equals(arg))
 	{
 	    new ConnectionsFrame(monitor);
@@ -307,21 +327,6 @@ public class Main extends MuffinFrame
 // 	{
 // 	    server.stop();
 // 	}
-	else if ("doSuspend".equals(arg))
-	{
-  	    suspendButton.setLabel("Resume");
- 	    suspendButton.setActionCommand("doResume");
- 	    server.suspend();
- 	    monitor.suspend();
-
-	}
-	else if ("doResume".equals(arg))
-	{
-  	    suspendButton.setLabel("Suspend");
- 	    suspendButton.setActionCommand("doSuspend");
- 	    server.resume();
- 	    monitor.resume();
-	}
 	else if ("doFilters".equals(arg))
 	{
 	    manager.createFrame();
@@ -439,7 +444,7 @@ public class Main extends MuffinFrame
     {
 	StringBuffer buf = new StringBuffer();
 	buf.append("Muffin version " + version +
-		   ", Copyright (C) 1996-1999 Mark R. Boyns <boyns@doit.org>\n");
+		   ", Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>\n");
 	buf.append("Muffin comes with ABSOLUTELY NO WARRANTY; for details see Help/License.\n");
 	buf.append("This is free software, and you are welcome to redistribute it\n");
 	buf.append("under certain conditions; see Help/License for details.\n");
@@ -614,8 +619,11 @@ public class Main extends MuffinFrame
 	{
 	    configs.setUserDirectory(args.getString("dir"));
 	}
-	configs.load();
+
+	/* Create Muffin dir if it doesn't exist */
+	configs.checkUserDirectory();
 	configs.scan();
+
 	String defaultConfig = "default.conf";
 	if (args.exists("conf"))
 	{
@@ -630,11 +638,8 @@ public class Main extends MuffinFrame
 	{
 	    defaultProps = args.getString("props");
 	}
+
 	options = new Options(defaultProps);
-	if (args.exists("dir"))
-	{
-	    options.setUserDirectory(args.getString("dir"));
-	}
 
 	try
 	{
@@ -692,7 +697,19 @@ public class Main extends MuffinFrame
 
 	options.sync();
 
-	logfile = new LogFile(options.getUserFile(options.getString("muffin.logfile")));
+	UserFile f = options.getUserFile(options.getString("muffin.logfile"));
+	if (f instanceof LocalFile)
+	{
+	    logfile = new LogFile(f.getName());
+	}
+	else
+	{
+	    logfile = null;
+	}
+
+	configs.setAutoConfigFile(options.getString("muffin.autoconfig"));
+	configs.load();
+
 	pool = new ThreadPool("Muffin Threads");
 
 	new Main();
