@@ -1,7 +1,7 @@
-/* $Id: Message.java,v 1.8 1999/11/06 23:23:02 boyns Exp $ */
+/* $Id: Message.java,v 1.12 2000/03/30 06:33:58 boyns Exp $ */
 
 /*
- * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of Muffin.
  *
@@ -25,11 +25,8 @@ package org.doit.muffin;
 import java.util.Hashtable;
 import java.util.Enumeration;
 import java.util.Vector;
-import java.io.PushbackInputStream;
-import java.io.InputStream;
-import java.io.InputStreamReader;
-import java.io.BufferedReader;
-import java.io.IOException;
+import java.io.*;
+import org.doit.io.*;
 
 /**
  * Abstract class to represent message headers.
@@ -48,7 +45,7 @@ public abstract class Message
      */
     String statusLine = null;
 
-    String readLine(InputStream in) throws IOException
+    public String readLine(InputStream in) throws IOException
     {
 	char buf[] = new char[128];
 	int offset = 0;
@@ -170,7 +167,7 @@ public abstract class Message
 	{
 	    return null;
 	}
-	return(String) v.elementAt(index);
+	return (String) v.elementAt(index);
     }
 
     public void setHeaderField(String name, String value)
@@ -209,6 +206,25 @@ public abstract class Message
 	setHeaderField(name, new Integer(value).toString(), index);
     }
 
+    /**
+     * Set all header fields with the give name to the
+     * specified value.
+     */
+    public void setHeaderFields(String name, String value)
+    {
+	Vector v;
+	Key key = new Key(name);
+
+	v = (Vector) headers.get(key);
+	if (v != null)
+	{
+	    for (int i = 0; i < v.size(); i++)
+	    {
+		v.setElementAt(value, i);
+	    }
+	}
+    }
+
     public void appendHeaderField(String name, String value)
     {
 	appendHeaderField(name, value, 0);
@@ -248,18 +264,13 @@ public abstract class Message
 
 	return v.elements();
     }
+
+    private final static byte[] COLON_SPACE = ": ".getBytes();
+    private final static byte[] CRLF = "\r\n".getBytes();
     
-    public String toString()
+    private ByteArray toByteArray(byte[] sep)
     {
-	return toString("\r\n");
-    }
-    
-    /**
-     * Return a string represenation of the headers.
-     */
-    public String toString(String sep)
-    {
-	StringBuffer buf = new StringBuffer();
+	ByteArray buf = new ByteArray();
 	Key key;
 	String value;
 	Vector v;
@@ -274,14 +285,41 @@ public abstract class Message
 	    v = (Vector) headers.get(key);
 	    for (i = 0; i < v.size(); i++)
 	    {
-		buf.append(key);
-		buf.append(": ");
-		buf.append(v.elementAt(i));
+		buf.append(key.toString());
+		buf.append(COLON_SPACE);
+		buf.append(v.elementAt(i).toString());
 		buf.append(sep);
 	    }
 	}
 	buf.append(sep);
 
-	return buf.toString();
+	return buf;
+    }
+
+    private ByteArray toByteArray()
+    {
+	return toByteArray(CRLF);
+    }
+
+    private ByteArray toByteArray(String sep)
+    {
+	return toByteArray(sep.getBytes());
+    }
+    
+    public String toString()
+    {
+	return toByteArray().toString();
+    }
+    
+    public String toString(String sep)
+    {
+	return toByteArray(sep).toString();
+    }
+
+    public void write(OutputStream out)
+	throws IOException
+    {
+	toByteArray().writeTo(out);
+	out.flush();
     }
 }
