@@ -1,4 +1,4 @@
-/* $Id: Prefs.java,v 1.6 2000/01/24 04:02:14 boyns Exp $ */
+/* $Id: Prefs.java,v 1.10 2000/04/03 05:05:43 boyns Exp $ */
 
 /*
  * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
@@ -25,9 +25,11 @@ package org.doit.muffin;
 import java.util.Hashtable;
 import java.util.StringTokenizer;
 import java.util.Enumeration;
-import java.io.File;
+import java.io.*;
 import java.awt.Color;
 import java.awt.Font;
+import java.net.URL;
+import java.net.MalformedURLException;
 import sdsu.compare.StringIgnoreCaseComparer;
 import sdsu.util.SortedList;
 
@@ -36,7 +38,21 @@ import sdsu.util.SortedList;
  */
 public class Prefs extends Hashtable
 {
-    String userDirectory = "Muffin";
+    private static String userDirectory = "Muffin";
+    private static String userHomeProperty;
+
+    static
+    {
+	if (System.getProperty("os.name").toLowerCase().startsWith("windows"))
+	{
+	    userHomeProperty = "user.dir";
+	    userDirectory = "";
+	}
+	else
+	{
+	    userHomeProperty = "user.home";
+	}
+    }
     
     boolean allowOverride = true;
     
@@ -62,13 +78,17 @@ public class Prefs extends Hashtable
 	{
 	    return userDirectory;
 	}
+
 	/* Use user.home */
-	else
+	StringBuffer sb = new StringBuffer();
+	sb.append(System.getProperty(userHomeProperty));
+	if (userDirectory != null && userDirectory.length() > 0)
 	{
-	    return System.getProperty("user.home") +
-		System.getProperty("file.separator") +
-		userDirectory;
+	    sb.append(System.getProperty("file.separator"));
+	    sb.append(userDirectory);
 	}
+
+	return sb.toString();
     }
 
     public void checkDirectory(String name)
@@ -89,13 +109,29 @@ public class Prefs extends Hashtable
 	checkDirectory(getUserDirectory());
     }
 
-    public String getUserFile(String file)
+    public UserFile getUserFile(String file)
     {
-	if (file.indexOf(System.getProperty("file.separator")) != -1)
+	UserFile userFile = null;
+	
+	try
 	{
-	    return file;
+	    userFile = new URLFile(new URL(file));
 	}
-	return getUserDirectory() + System.getProperty("file.separator") + file;
+	catch (MalformedURLException e)
+	{
+	    if (file.indexOf(System.getProperty("file.separator")) != -1)
+	    {
+		userFile = new LocalFile(file);
+	    }
+	    else
+	    {
+		userFile = new LocalFile(getUserDirectory() +
+					 System.getProperty("file.separator") +
+					 file);
+	    }
+	}
+
+	return userFile;
     }
 
     public boolean exists(Object key)
@@ -166,6 +202,20 @@ public class Prefs extends Hashtable
 	return val;
     }
 
+    public long getLong(String key)
+    {
+	long val;
+	try
+	{
+	    val = Long.parseLong(getString(key));
+	}
+	catch (NumberFormatException e)
+	{
+	    val = -1;
+	}
+	return val;
+    }
+
     String toHexString(int value, int length)
     {
 	String s = Integer.toHexString(value);
