@@ -1,7 +1,7 @@
-/* $Id: NoThanks.java,v 1.5 1999/05/29 17:34:24 boyns Exp $ */
+/* $Id: NoThanks.java,v 1.13 2000/03/29 15:14:00 boyns Exp $ */
 
 /*
- * Copyright (C) 1996-99 Mark R. Boyns <boyns@doit.org>
+ * Copyright (C) 1996-2000 Mark R. Boyns <boyns@doit.org>
  *
  * This file is part of Muffin.
  *
@@ -27,12 +27,7 @@ import org.doit.html.*;
 import java.util.Hashtable;
 import java.util.Vector;
 import java.util.Enumeration;
-import java.io.File;
-import java.io.FileReader;
-import java.io.BufferedReader;
-import java.io.Reader;
-import java.io.StringReader;
-import java.io.StreamTokenizer;
+import java.io.*;
 import gnu.regexp.*;
 
 public class NoThanks implements FilterFactory
@@ -41,7 +36,7 @@ public class NoThanks implements FilterFactory
     Prefs prefs;
     NoThanksFrame frame = null;
     MessageArea messages = null;
-    
+
     private RE kill = null;
     private RE comment = null;
     private RE content = null;
@@ -57,12 +52,21 @@ public class NoThanks implements FilterFactory
     private StringBuffer killBuffer = null;
     private StringBuffer commentBuffer = null;
     private StringBuffer contentBuffer = null;
+    private Vector scriptPatterns = null;
+    private Vector scriptReplace = null;
+    private Vector scriptStrip = null;
+    private Hashtable headerStrip = new Hashtable();
+    private Hashtable headerReplace = new Hashtable();
+    private Hashtable headerReplaceValue = null;
 
     private RE hyperTags = null;
     private RE hyperAttrs = null;
     private RE hyperEnd = null;
     private RE requiredTags = null;
 
+    // RE compilation cflags
+    private int cflags = 0;
+
     public NoThanks()
     {
 	try
@@ -89,7 +93,7 @@ public class NoThanks implements FilterFactory
 	this.prefs = prefs;
 	boolean o = prefs.getOverride();
 	prefs.setOverride(false);
-	String filename = prefs.getUserFile("killfile");
+	String filename = "killfile";
 	prefs.putString("NoThanks.killfile", filename);
 	prefs.setOverride(o);
 	messages = new MessageArea();
@@ -313,6 +317,108 @@ public class NoThanks implements FilterFactory
 	return false;
     }
 
+    Token processScript(Request request, Token token)
+    {
+	RE re;
+	String replace;
+	String script;
+	int size;
+
+	script = token.toString();
+
+	//
+	// See if any of the scriptStrip patterns match.
+	//
+	if (scriptStrip.size() > 0)
+	{
+	    for (Enumeration e = scriptStrip.elements(); e.hasMoreElements(); )
+	    {
+		re = (RE) e.nextElement();
+		if (re.getMatch(script) != null)
+		{
+		    // strip this script
+		    report(request, "script stripped " + re.toString());
+		    return null;
+		}
+	    }
+	}
+
+	//
+	// Perform regexp-based script substitution.
+	//
+	if ((size = scriptPatterns.size()) > 0)
+	{
+	    for (int i = 0; i < size; i++)
+	    {
+		re = (RE) scriptPatterns.elementAt(i);
+		replace = (String)scriptReplace.elementAt(i);
+		script = re.substituteAll(script, replace);
+	    }
+
+	    token = new Token(token.getType());
+	    token.append(script);
+	}
+
+	return token;
+    }
+
+    void processHeaders(Request request, Message m)
+    {
+	// try to optimize for the case where there are no
+	// header rules
+	if (headerStrip.size() == 0 && headerReplace.size() == 0)
+	{
+	    return;
+	}
+	
+	String name, value;
+	RE re;
+	REMatch match;
+
+	for (Enumeration e = m.getHeaders(); e.hasMoreElements(); )
+	{
+	    name = ((String) e.nextElement()).toLowerCase();
+
+	    if (headerStrip.containsKey(name))
+	    {
+		re = (RE) headerStrip.get(name);
+		for (int i = 0, n = m.getHeaderValueCount(name); i < n; i++)
+		{
+		    value = m.getHeaderField(name, i);
+		    if (compare(value, re))
+		    {
+			report(request, "header "+name+"="+value+" stripped");
+			m.removeHeaderField(name);
+			break;
+		    }
+		}
+	    }
+	    if (headerReplace.containsKey(name))
+	    {
+		Vector v = (Vector) headerReplace.get(name);
+		Vector vv = (Vector) headerReplaceValue.get(name);
+		for (int index = 0; index < v.size(); index++)
+		{
+		    re = (RE) v.elementAt(index);
+
+		    for (int i = 0, n = m.getHeaderValueCount(name); i < n; i++)
+		    {
+			value = m.getHeaderField(name, i);
+			match = re.getMatch(value);
+			if (match != null)
+			{
+			    String replace = (String) vv.elementAt(index);
+			    replace = match.substituteInto(replace);
+			    report(request, "header " + name + " replaced \""
+				   + value + "\" with \"" + replace + "\"");
+			    m.setHeaderField(name, replace, i);
+			}
+		    }
+		}
+	    }
+	}
+    }
+
     void save()
     {
 	manager.save(this);
@@ -331,24 +437,45 @@ public class NoThanks implements FilterFactory
 	    }
 	}
 	buf.append(")");
-	return new RE(buf.toString());
+	return new RE(buf.toString(), cflags);
     }
 
     void load()
     {
-	String filename = prefs.getUserFile(prefs.getString("NoThanks.killfile"));
+	InputStream in = null;
+
 	try
 	{
-	    //System.out.println("NoThanks loading " + filename);
-	    load(new FileReader(new File(filename)));
+	    UserFile file = prefs.getUserFile(prefs.getString("NoThanks.killfile"));
+	    in = file.getInputStream();
+	    load(new InputStreamReader(in));
 	}
-	catch (Exception e)
+	catch (FileNotFoundException e)
 	{
 	}
+	catch (IOException e)
+	{
+	    System.out.println(e);
+	}
+	finally
+	{
+	    if (in != null)
+	    {
+		try
+		{
+		    in.close();
+		}
+		catch (IOException e)
+		{
+		}
+	    }
+	}
     }
 
     void load(Reader reader)
     {
+	cflags = 0;
+	
 	strip = new Hashtable(33);
 	redirectPatterns = new Vector();
 	redirectLocations = new Vector();
@@ -361,14 +488,23 @@ public class NoThanks implements FilterFactory
 	killBuffer = new StringBuffer();
 	commentBuffer = new StringBuffer();
 	contentBuffer = new StringBuffer();
+	scriptPatterns = new Vector();
+	scriptReplace = new Vector();
+	scriptStrip = new Vector();
+	headerStrip = new Hashtable();
+	headerReplace = new Hashtable();
+	headerReplaceValue = new Hashtable();
 
 	include(reader);
 	
 	try
 	{
-	    kill = (killBuffer.length() > 0) ? new RE("(" + killBuffer.toString() + ")") : null;
-	    comment = (commentBuffer.length() > 0) ? new RE("(" + commentBuffer.toString() + ")") : null;
-	    content = (contentBuffer.length() > 0) ? new RE("(" + contentBuffer.toString() + ")") : null;
+	    kill = (killBuffer.length() > 0) ?
+		new RE("(" + killBuffer.toString() + ")", cflags) : null;
+	    comment = (commentBuffer.length() > 0) ?
+		new RE("(" + commentBuffer.toString() + ")", cflags) : null;
+	    content = (contentBuffer.length() > 0) ?
+		new RE("(" + contentBuffer.toString() + ")", cflags) : null;
 
 	    /* Build regular expressions for tagattr */
 	    Enumeration e = tagattrStrip.keys();
@@ -383,6 +519,14 @@ public class NoThanks implements FilterFactory
 		String key = (String) e.nextElement();
 		tagattrRemove.put(key, createRE((Vector) tagattrRemove.get(key)));
 	    }
+
+	    /* Build regular expressions for header */
+	    e = headerStrip.keys();
+	    while (e.hasMoreElements())
+	    {
+		String key = (String) e.nextElement();
+		headerStrip.put(key, createRE((Vector) headerStrip.get(key)));
+	    }
 	}
 	catch (REException e)
 	{
@@ -425,8 +569,31 @@ public class NoThanks implements FilterFactory
 			{
 			    break;
 			}
-			String filename = prefs.getUserFile(st.sval);
-			include(new FileReader(new File(filename)));
+
+			InputStream inc = null;
+			try
+			{
+			    UserFile file = prefs.getUserFile(st.sval);
+			    inc = file.getInputStream();
+			    include(new InputStreamReader(inc));
+			}
+			catch (IOException e)
+			{
+			    System.out.println(e);
+			}
+			finally
+			{
+			    if (inc != null)
+			    {
+				try
+				{
+				    inc.close();
+				}
+				catch (IOException e)
+				{
+				}
+			    }
+			}
 		    }
 		    continue;
 		}
@@ -502,7 +669,7 @@ public class NoThanks implements FilterFactory
 		    }
 		    try
 		    {
-			RE re = new RE(pattern);
+			RE re = new RE(pattern, cflags);
 			redirectPatterns.addElement(re);
 			redirectLocations.addElement(location);
 		    }
@@ -584,7 +751,7 @@ public class NoThanks implements FilterFactory
 			pattern = new String(st.sval);
 		    }
 
-		    RE re = new RE(pattern);
+		    RE re = new RE(pattern, cflags);
 		
 		    if (command.equals("strip"))
 		    {
@@ -649,6 +816,160 @@ public class NoThanks implements FilterFactory
 			System.out.println("tagattr " + command + " unknown command");
 		    }
 		}
+		else if (st.sval.equals("options"))
+		{
+		    token = st.nextToken();
+		    if (token != StreamTokenizer.TT_WORD && token != '"')
+		    {
+			break;
+		    }
+
+		    if ("reg-case".equals(st.sval))
+		    {
+			cflags = 0;
+		    }
+		    else if ("reg-icase".equals(st.sval))
+		    {
+			cflags = RE.REG_ICASE;
+		    }
+		}
+		else if (st.sval.equals("script"))
+		{
+		    token = st.nextToken();
+		    if (token != StreamTokenizer.TT_WORD && token != '"')
+		    {
+			break;
+		    }
+		    
+		    if ("replace".equals(st.sval))
+		    {
+			String pattern;
+
+			token = st.nextToken();
+			if (token != StreamTokenizer.TT_WORD && token != '"')
+			{
+			    pattern = ".*";
+			}
+			else
+			{
+			    pattern = new String(st.sval);
+			}
+
+			RE re = new RE(pattern, cflags);
+			scriptPatterns.addElement(re);
+
+			token = st.nextToken();
+			if (token != StreamTokenizer.TT_WORD && token != '"')
+			{
+			    System.out.println("script replace missing replacement");
+			}
+			else
+			{
+			    scriptReplace.addElement(st.sval);
+			}
+		    }
+		    else if ("strip".equals(st.sval))
+		    {
+			String pattern;
+
+			token = st.nextToken();
+			if (token != StreamTokenizer.TT_WORD && token != '"')
+			{
+			    pattern = ".*";
+			}
+			else
+			{
+			    pattern = new String(st.sval);
+			}
+
+			RE re = new RE(pattern, cflags);
+			scriptStrip.addElement(re);
+		    }
+		    else
+		    {
+			System.out.println("script " + st.sval + " unknown command");
+		    }
+		}
+		else if (st.sval.equals("header"))
+		{
+		    // header
+		    token = st.nextToken();
+		    if (token != StreamTokenizer.TT_WORD && token != '"')
+		    {
+			break;
+		    }
+		    String key = st.sval.toLowerCase();
+
+		    // command
+		    token = st.nextToken();
+		    if (token != StreamTokenizer.TT_WORD && token != '"')
+		    {
+			break;
+		    }
+		    String command = new String(st.sval);
+
+		    // value pattern
+		    String pattern;
+		    token = st.nextToken();
+		    if (token != StreamTokenizer.TT_WORD && token != '"')
+		    {
+			pattern = ".*";
+		    }
+		    else
+		    {
+			pattern = new String(st.sval);
+		    }
+
+		    RE re = new RE(pattern, cflags);
+
+		    if (command.equals("strip"))
+		    {
+			/* Build a vector of Strings */
+			Vector v;
+			if (headerStrip.containsKey(key))
+			{
+			    v = (Vector) headerStrip.get(key);
+			}
+			else
+			{
+			    v = new Vector();
+			    headerStrip.put(key, v);
+			}
+			v.addElement(pattern);
+		    }
+		    else if (command.equals("replace"))
+		    {
+			token = st.nextToken();
+			if (token != StreamTokenizer.TT_WORD && token != '"')
+			{
+			    System.out.println("header replace missing value");
+			    break;
+			}
+			String value = new String(st.sval);
+
+			/* Build a vector of REs and replacement Strings */
+			Vector v;
+			Vector vv;
+			if (headerReplace.containsKey(key))
+			{
+			    v = (Vector) headerReplace.get(key);
+			    vv = (Vector) headerReplaceValue.get(key);
+			}
+			else
+			{
+			    v = new Vector();
+			    vv = new Vector();
+			    headerReplace.put(key, v);
+			    headerReplaceValue.put(key, vv);
+			}
+			v.addElement(re);
+			vv.addElement(value);
+		    }
+		    else
+		    {
+			System.out.println("header " + command + " unknown command");
+		    }
+		}
 		else
 		{
 		    System.out.println("NoThanks: " + st.sval + " unknown command");
