@@ -27,13 +27,9 @@ package org.doit.muffin.filter;
 
 import java.awt.*;
 import java.awt.event.*;
-import java.io.File;
-import java.io.BufferedReader;
-import java.io.FileReader;
-import java.io.FileWriter;
-import java.io.StringReader;
-import java.io.Reader;
+import java.io.*;
 import org.doit.muffin.*;
+import org.doit.util.*;
 
 public class TranslateFrame extends MuffinFrame
     implements ActionListener, WindowListener
@@ -165,42 +161,69 @@ public class TranslateFrame extends MuffinFrame
     void loadFile()
     {
 	text.setText("");
-	
-	File file = new File(prefs.getString("Translate.rules"));
-	if (!file.exists())
-	{
-	    return;
-	}
+
+	UserFile file = prefs.getUserFile(prefs.getString("Translate.rules"));
+	InputStream in = null;
 	
 	try
 	{
-	    BufferedReader in = new BufferedReader(new FileReader(file));
+	    in = file.getInputStream();
+
+	    BufferedReader br = new BufferedReader(new InputStreamReader(in));
 	    String s;
-	    while ((s = in.readLine()) != null)
+	    while ((s = br.readLine()) != null)
 	    {
 		text.append(s + "\n");
 	    }
+	    br.close();
 	    in.close();
+	    in = null;
 	    text.setCaretPosition(0);
 	}
-	catch (Exception e)
+	catch (FileNotFoundException e)
+	{
+	}
+	catch (IOException e)
 	{
 	    System.out.println(e);
 	}
+	finally
+	{
+	    try
+	    {
+		if (in != null)
+		{
+		    in.close();
+		}
+	    }
+	    catch (IOException e)
+	    {
+	    }
+	}
+	
     }
 
     void saveFile()
     {
 	try
 	{
-	    File file = new File(prefs.getString("Translate.rules"));
-	    if (file.exists())
+	    UserFile file = prefs.getUserFile(prefs.getString("Translate.rules"));
+	    if (file instanceof LocalFile)
 	    {
-		file.delete();
+		LocalFile f = (LocalFile) file;
+		f.delete();
+		OutputStream out = file.getOutputStream();
+		Writer writer = new OutputStreamWriter(out);
+		writer.write(text.getText());
+		writer.close();
+		out.close();
+	    }
+	    else
+	    {
+		Dialog d = new ErrorDialog(this, "Can't save to " + file.getName());
+		d.show();
+		d.dispose();
 	    }
-	    FileWriter writer = new FileWriter(file);
-	    writer.write(text.getText());
-	    writer.close();
 	}
 	catch (Exception e)
 	{
